PersistedData<DataT> class final

A state representation of how the data is persisted.

This includes the data itself, along with various metadata that should also be persisted.

Annotations
  • @immutable

Constructors

PersistedData(DataT data, {String? destroyKey, DateTime? expireAt})
A state representation of how the data is persisted.
const

Properties

data → DataT
The persisted data.
final
destroyKey → String?
The key passed to StorageOptions.destroyKey.
final
expireAt → DateTime?
The date at which the data expires.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override