ProviderTransformer2<InT, ValueT, ListenableT extends CustomProviderListenable<InT, ValueT>> class abstract base

The logic responsible for transforming a ProviderListenable into another ProviderListenable.

It is both:

  • the object that hols the current state of the transformation
  • a description of how to react to various life-cycles related to the listened object.
Implementers
Annotations
  • @publicInMisc

Constructors

ProviderTransformer2()

Properties

hashCode int
The hash code for this object.
no setterinherited
listenable → ListenableT
The CustomProviderListenable that created this transformer.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceState AsyncResult<InT>
The current state of CustomProviderListenable.source.
no setter
state AsyncResult<ValueT>
The currently exposed state of this transformer.
getter/setter pair

Methods

initState() → ValueT
Initializes the state of this transformer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClose() → void
A life-cycle method for when the ProviderSubscription obtained from CustomProviderListenable is closed.
onEvent(AsyncResult<InT> prev, AsyncResult<InT> next) → void
A life-cycle method invoked when CustomProviderListenable.source. changes after the initial event.
pause() → void
Pauses the subscription to CustomProviderListenable.source., stopping it from being notified of any change until resume is called.
read() → InT
Reads the latest value of CustomProviderListenable.source., bypassing the pause state.
resume() → void
Resumes the subscription to CustomProviderListenable.source. after a call to pause.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited