originProvider property
The provider that will be refreshed when calling ProviderContainer.refresh
and that will be overridden when passed to ProviderScope.
Defaults to this.
Implementation
@override
ProviderBase<State> get originProvider => this;