ProviderBase<StateT> class abstract

A base class for all providers.

Inheritance
Implemented types
Mixed-in types
Implementers
Available extensions
Annotations
  • @immutable

Constructors

ProviderBase({required String? name, required Family<Object?>? from, required Object? argument, required DebugGetCreateSourceHash? debugGetCreateSourceHash, required Iterable<ProviderOrFamily>? dependencies, required Iterable<ProviderOrFamily>? allTransitiveDependencies})
A base class for all providers.
const

Properties

allTransitiveDependencies → Iterable<ProviderOrFamily>?
All the dependencies of a provider and their dependencies too.
finalinherited
argument → Object?
If this provider was created with the .family modifier, argument is the variable that was used.
final
dependencies → Iterable<ProviderOrFamily>?
The list of providers that this provider potentially depends on.
finalinherited
from → Family<Object?>?
If this provider was created with the .family modifier, from is the .family instance.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String?
A custom label for providers.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(Node node, void listener(StateT? previous, StateT next), {required void onError(Object error, StackTrace stackTrace)?, required void onDependencyMayHaveChanged()?, required bool fireImmediately}) → ProviderSubscription<StateT>
Starts listening to this transformer
override
createElement() → ProviderElementBase<StateT>
An internal method that defines how a provider behaves.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overrideWithProvider(ProviderType override) → Override

Available on ProviderType, provided by the OverrideWithProviderExtension extension

Overrides a provider with a value, ejecting the default behaviour.
read(Node node) → StateT
Obtains the result of this provider expression without adding listener.
override
select<Selected>(Selected selector(StateT value)) → ProviderListenable<Selected>
Partially listen to a provider.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override