riverpod library
Classes
-
AnyNotifier<
StateT, ValueT> Notifiers - A base class for all "notifiers".
-
AsyncData<
ValueT> Core - Creates an AsyncValue with a data.
-
AsyncError<
ValueT> Core - Creates an AsyncValue in the error state.
-
AsyncLoading<
ValueT> Core - Creates an AsyncValue in loading state.
-
AsyncNotifier<
StateT> Notifiers - A Notifier implementation that is asynchronously initialized.
-
AsyncNotifierProvider<
NotifierT extends AsyncNotifier< ProvidersValueT> , ValueT> - A provider which creates and listen to an AsyncNotifier.
-
AsyncResult<
ValueT> - A variant of AsyncValue that excludes AsyncLoading.
-
AsyncValue<
ValueT> Core - A utility for safely manipulating asynchronous data.
-
FutureProvider<
ValueT> Providers - A provider that asynchronously creates a value.
-
Notifier<
ValueT> Notifiers - A class which exposes a state that can change over time.
-
NotifierProvider<
NotifierT extends Notifier< ProvidersValueT> , ValueT> - A provider that exposes a synchronous Notifier.
-
Provider<
ValueT> Providers - A provider that exposes a read-only value.
- ProviderContainer Core
- An object that stores the state of the providers and allows overriding the behavior of a specific provider.
- ProviderObserver Core
- An object that listens to the changes of a ProviderContainer.
- ProviderObserverContext Core
- Information about the ProviderObserver event.
-
ProviderSubscription<
OutT> Core - Represents the subscription to a ProviderListenable.
- Ref Core
- An object used by providers to interact with other providers and the life-cycles of the application.
-
StreamNotifier<
ValueT> Notifiers - A variant of AsyncNotifier which has build creating a Stream.
-
StreamNotifierProvider<
NotifierT extends StreamNotifier< ProvidersValueT> , ValueT> - A provider which creates and listen to an StreamNotifier.
-
StreamProvider<
ValueT> Providers - Creates a stream and exposes its latest event.
Extensions
-
AsyncValueExtensions
on AsyncValue<
ValueT> - Adds non-state related methods/getters to AsyncValue.
-
ProviderListenableSelect
on ProviderListenable<
InT> - Adds select to ProviderListenable.
Exceptions / Errors
- AsyncValueIsLoadingException
- AsyncValue.requireValue was called on an AsyncValue with no error nor a value.