initState abstract method
ValueT
initState()
Initializes the state of this transformer.
This is called lazily, the first time the state of this transformer is read, and its return value is used as the initial state.
Implementation
ValueT initState();