SyncProviderTransformer2<InT, ValueT, ListenableT extends CustomProviderListenable<InT, ValueT> > class
abstract
base
A variant of ProviderTransformer2 for CustomProviderListenables that do not emit AsyncValue.
If in error state, an exception will happen when trying to read the state of the associated CustomProviderListenable.
See CustomProviderListenable for a usage example.
- Inheritance
-
- Object
- ProviderTransformer2<
InT, ValueT, ListenableT> - SyncProviderTransformer2
- Annotations
-
- @publicInMisc
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- listenable → ListenableT
-
The CustomProviderListenable that created this transformer.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceState
→ AsyncResult<
InT> -
The current state of CustomProviderListenable.source.
no setterinherited
-
state
↔ AsyncResult<
ValueT> -
The currently exposed state of this transformer.
getter/setter pairinherited
Methods
-
initState(
) → ValueT -
Initializes the state of this transformer.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
) → void -
A life-cycle method for when the ProviderSubscription obtained from
CustomProviderListenable is closed.
inherited
-
onEvent(
AsyncResult< InT> prev, AsyncResult<InT> next) → void -
A life-cycle method invoked when CustomProviderListenable.source. changes after the initial
event.
inherited
-
pause(
) → void -
Pauses the subscription to CustomProviderListenable.source., stopping it from being notified
of any change until resume is called.
inherited
-
read(
) → InT -
Reads the latest value of CustomProviderListenable.source., bypassing the pause state.
inherited
-
resume(
) → void -
Resumes the subscription to CustomProviderListenable.source. after a call to pause.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited